import React, { ReactNode } from 'react';
interface ISlideoverContextProps {
    /**
     * Defines the slide over open in the context
     */
    isOpen: boolean;
    /**
     * Defines the setting the slide over open in the context
     */
    setOpenState: (open: boolean) => void;
}
export interface ISlideoverProps extends React.ComponentPropsWithoutRef<'div'> {
    /**
     * Defines the focus delay to focus container
     * to trigger Escape event
     */
    focusDelay?: number;
    /**
     * Defines the slideover order on the DOM based on the z-{index} class
     */
    zIndex?: string;
    /**
     * Defines the top spacing of the slide-over
     */
    top?: string;
    /**
     * Defines the max width of the slide-over, e.g. max-w-md, max-w-2xl, max-w-3xl
     */
    wider?: string;
    /**
     * Defines the outside close icon
     */
    outSideClose?: boolean;
    /**
     * Defines the outside icon
     */
    iconClass?: string;
    /**
     * Defines the slide over open
     */
    isOpen: boolean;
    /**
     * Defines the call back on close
     */
    onClose: () => void;
    /**
     * Defines the call back when "Escape"
     */
    onDismiss?: (event: React.SyntheticEvent | Event) => void;
}
export declare const SlideoverContext: React.Context<ISlideoverContextProps>;
declare const Slideover: ({ focusDelay, className, zIndex, top, wider, outSideClose, iconClass, isOpen, onClose, onDismiss, onKeyDown, children, ...other }: ISlideoverProps) => JSX.Element;
export default Slideover;
export interface IHeaderProps extends Omit<React.ComponentPropsWithoutRef<'header'>, 'title'> {
    /**
     * Defines the close icon to show
     */
    showCloseIcon?: boolean;
    /**
     * Defines the header background color
     */
    brandColor?: string;
    /**
     * Defines the close icon
     */
    iconClass?: string;
    /**
     * Defines the header title
     */
    title: ReactNode;
    /**
     * Defines the description area in the header
     */
    description?: ReactNode;
}
export declare function SlideoverHeader({ showCloseIcon, brandColor, iconClass, title, description, ...other }: IHeaderProps): JSX.Element;
interface ISlideoverFooterProps extends React.ComponentPropsWithoutRef<'footer'> {
    /**
     * Defines the rendering children as render props
     */
    children: (props: {
        setOpenState: (open: boolean) => void;
    }) => ReactNode;
}
export declare function SlideoverFooter({ className, children, ...other }: ISlideoverFooterProps): JSX.Element;
export declare function SlideoverContent({ className, children, ...other }: any): JSX.Element;
//# sourceMappingURL=Slideover.d.ts.map